# Summary

[Introduction](introduction.md)

# Getting Started

- [Installation](getting-started/installation.md)
- [Quick Start](getting-started/quick-start.md)
- [Configuration](getting-started/configuration.md)

# Guide

- [Commands](guide/commands.md)
- [Document Format](guide/document-format.md)
- [Run Flow](guide/submit-flow.md)
- [Editor Integration](guide/editor-integration.md)
- [Agent Backends](guide/agent-backends.md)

# Development

- [Building](development/building.md)
- [Conventions](development/conventions.md)

# Reference

- [Specification](reference/specs.md)
- [Changelog](reference/changelog.md)
